@@ -1,6 +1,6 @@
 from src import logger_instance
 
-def custom_log(log_type, msg, module_name='', error_code='', *args, **kwargs):
+def log(log_type, msg, module_name='', error_code='', *args, **kwargs):
     formatted_msg = f"error_code={error_code}, module_name={module_name}, message={msg}"
     if log_type.lower() == 'info':
         logger_instance.info(formatted_msg, *args, **kwargs)
